@@ -1,5 +1,5 @@
 package Telegram::Bot::Brain;
-$Telegram::Bot::Brain::VERSION = '0.010';
+$Telegram::Bot::Brain::VERSION = '0.011';
 # ABSTRACT: A base class to make your very own Telegram bot
 
 
@@ -82,13 +82,10 @@ sub send_to_chat_id {
   my $method = $message->send_method;
   my $msgURL = "https://api.telegram.org/bot${token}/send". $method;
 
-  my $tx = $self->ua->post($msgURL, form => { chat_id => $chat_id, %{ $message->as_hashref }, %$args});
-  if (my $res = $tx->success) { return $tx->res->json->{result}; }
-  else {
-    my $err = $tx->error;
-    die "$err->{code} response: $err->{message}\nBody: " . $tx->res->body if $err->{code};
-    die "Connection error: $err->{message}\nBody: " . $tx->res->body;
-  }
+  my $res = $self->ua->post($msgURL, form => { chat_id => $chat_id, %{ $message->as_hashref }, %$args})->result;
+  if    ($res->is_success) { return $res->json->{result}; }
+  elsif ($res->is_error)   { die "Failed to post: " . $res->message; }
+  else                     { die "Not sure what went wrong"; }
 }
 
 
@@ -101,13 +98,10 @@ sub send_message_to_chat_id {
   my $token = $self->token;
   my $msgURL = "https://api.telegram.org/bot${token}/sendMessage";
 
-  my $tx = $self->ua->post($msgURL, form => { %$args, chat_id => $chat_id, text => $message });
-  if (my $res = $tx->success) { return $tx->res->json->{result}; }
-  else {
-    my $err = $tx->error;
-    die "$err->{code} response: $err->{message}\nBody: " . $tx->res->body if $err->{code};
-    die "Connection error: $err->{message}\nBody: " . $tx->res->body;
-  }
+  my $res = $self->ua->post($msgURL, form => { %$args, chat_id => $chat_id, text => $message })->result;
+  if    ($res->is_success) { return $res->json->{result}; }
+  elsif ($res->is_error)   { die "Failed to post: " . $res->message; }
+  else                     { die "Not sure what went wrong"; }
 }
 
 sub add_getUpdates_handler {
@@ -178,7 +172,7 @@ Telegram::Bot::Brain - A base class to make your very own Telegram bot
 
 =head1 VERSION
 
-version 0.010
+version 0.011
 
 =head1 SYNOPSIS
 
